@@ -5,7 +5,7 @@ use warnings;
 
 use lib 't';
 use Dancer ':syntax';
-load_plugin 'TestPlugin';
+use TestPlugin;
 
 sub test_app_func { test_plugin_symbol() }
 
